@@ -11,6 +11,7 @@ The FireCurve module supports definition of temperature-time curves for SFE.
 
 import numpy as np
 import math as m
+from scipy.interpolate import interp1d
 
 ############
 ## MODULE ##
@@ -48,6 +49,32 @@ def ISO834(time):
 	return 20+345*np.log10(8*time+1)
 
 
+def ASTM(time):
+	""" Return ASTM-E119 gas temperature at specified times
+
+	Parameters
+	----------
+	time :	np.array
+		array of time instants [min]
+
+	Returns
+	-------
+	fire :	np.array
+		array of gas temperatures for time [C]
+
+	Reference
+	---------
+	ASTM E119-00a: Fire Tests of Building Construction and Materials
+	via https://www.nrc.gov/docs/ML0516/ML051640380.pdf
+
+	"""
+	t_list = np.array([0,5,10,20,30,60,90,120,180,240,300,360,420,480]) # [min]
+	T_list = np.array([68,1000,1300,1462,1550,1700,1792,1850,1925,2000,2075,2150,2225,2300]) # [°F]
+	T_list = (T_list-32)*5/9 # conversion °F -> °C
+	T_data = interp1d(t_list,T_list)
+	return T_data(time)
+
+
 def EuroCodeParametric(time, openingFactor, fireLoadDensity, thermalInertia=1450, length=10, width=10, height=3, t_lim = 20, Reitgruber=False):
 	""" Return Eurocode Parametric fire gas temperature at specified times
 
@@ -132,4 +159,4 @@ def EuroCodeParametric(time, openingFactor, fireLoadDensity, thermalInertia=1450
 
 if __name__ == "__main__":
 
-	print("testing")
+	print("testing")
\ No newline at end of file
