@@ -1,7 +1,3 @@
-#__author__ = "magnelPy"
-#__email__= "ruben.vancoile@ugent.be"
-#__date__= "2018-10-11"
-
 ####################
 ## MODULE IMPORTS ##
 ####################
@@ -17,17 +13,11 @@ from magnelPy.admin import df_writeToExcel
 from magnelPy.stochVar import createStochVar,fx
 
 
-# import sys
-# magnelpyPath="C:/Users/rvcoile/Google Drive/Research/Codes/MagnelPy/magnelPy"
-# directory=magnelpyPath
-# sys.path.append(directory)
-# import statFunc
-
 ##############
 ## FUNCTION ##
 ##############
 
-def LHS(N, K, RedCor = False, MidPoint = False ):
+def LHS(N, K, RedCor = False, MidPoint = False, Legacy=False ):
 	#------------------------------------------------------------------------------------------------------------
 	# This function generates a Latin Hypercube consisting of N realizations of each of the K random variables
 	#
@@ -36,6 +26,7 @@ def LHS(N, K, RedCor = False, MidPoint = False ):
 	# 	K = the number of random variables
 	# 	RedCor = switch the option to reduce spurious correlation on/off (True/False)
 	#	MidPoint = switch the option to take the midpoint value of each interval (True/False)
+	#	Legacy = switch to use old (slower) code - new code has been verified; legacy option as part of risk management
 	#
 	# Output:
 	#	numpy.ndarray : NxK array with LHS realizations (r-values between 0 and 1)
@@ -72,11 +63,13 @@ def LHS(N, K, RedCor = False, MidPoint = False ):
 			print("________________________________________________________________________________")
 			return None
 		else:
-			Y = np.array([ [ stats.norm.ppf(float(P[i][j])/(N + 1)) for j in range(K) ] for i in range(N)])
+			if Legacy: Y = np.array([ [ stats.norm.ppf(float(P[i][j])/(N + 1)) for j in range(K) ] for i in range(N)])
+			else: Y=statFunc.Finv_Normal(P/(N+1),0,1)
 			covY = np.cov(np.transpose(Y))
 			L = np.linalg.cholesky(covY)
 			Ystar = np.dot(Y, np.transpose(np.linalg.inv(L)))
-			Pstar = np.transpose(np.array([ [sorted(Ystar[:,i]).index(v) + 1 for v in Ystar[:,i]] for i in range(K)]))
+			if Legacy: Pstar = np.transpose(np.array([ [sorted(Ystar[:,i]).index(v) + 1 for v in Ystar[:,i]] for i in range(K)]))
+			else: Pstar = Ystar.argsort(axis=0).argsort(axis=0)+1
 			P = Pstar
 
 	# Generate the matrix R of independent random numbers from the uniform distribution
