@@ -379,6 +379,13 @@ def F_Birnbaum_Saunders(x,m,s):
 	c,scale=p_Birnbaum_Saunders(m,s)
 	return fatiguelife.cdf(x,c,loc=0,scale=scale)
 
+def F_Lognormal_truncated(x,m,s,b):
+	#--------------------------------------------------------------------------------------------------------
+	# X ~ truncated lognormal distribution
+	# Input: r,m,s,b (b = upper bound)
+	#--------------------------------------------------------------------------------------------------------
+	return F_Lognormal(x,m,s)/F_Lognormal(b,m,s)
+
 ## PDF function ##
 ##################
 #------------------------------------------------------------------------------------------------------------
